# Shared python package

This package contains shared Python scripts and modules that are used across multiple projects.

> [!IMPORTANT]
> Each of them has a specific use case for the shared scripts and modules.
> please refer to the README.md file in each repository for more information.

## License
This package is licensed under the MIT License. See the [LICENSE](./LICENSE) file for more information.
